@@ -169,23 +169,28 @@ def make_order_by_deterministic(query):
 
     .. versionadded: 0.27.1
     """
-    if not query._order_by:
-        return query
+    order_by_func = sa.asc
 
-    order_by = query._order_by[0]
-    if isinstance(order_by, sa.sql.expression.UnaryExpression):
-        if order_by.modifier == sa.sql.operators.desc_op:
-            order_by_func = sa.desc
-        else:
-            order_by_func = sa.asc
-        column = order_by.get_children()[0]
+    if not query._order_by:
+        column = None
     else:
-        column = order_by
-        order_by_func = sa.asc
+        order_by = query._order_by[0]
+        if isinstance(order_by, sa.sql.expression.UnaryExpression):
+            if order_by.modifier == sa.sql.operators.desc_op:
+                order_by_func = sa.desc
+            else:
+                order_by_func = sa.asc
+            column = order_by.get_children()[0]
+        else:
+            column = order_by
 
     # Queries that are ordered by an already
-    if isinstance(column, sa.Column) and has_unique_index(column):
-        return query
+    if isinstance(column, sa.Column):
+        try:
+            if has_unique_index(column):
+                return query
+        except TypeError:
+            return query
 
     base_table = get_tables(query._entities[0])[0]
     query = query.order_by(
